@@ -6,13 +6,15 @@ import pyarrow as pa
 import pyarrow.compute as pc
 
 from narwhals._arrow.utils import ArrowSeriesNamespace
+from narwhals._utils import not_implemented
 
 if TYPE_CHECKING:
-    from typing_extensions import Self
-
     from narwhals._arrow.series import ArrowSeries
 
 
 class ArrowSeriesListNamespace(ArrowSeriesNamespace):
-    def len(self: Self) -> ArrowSeries:
-        return self.from_native(pc.list_value_length(self.native).cast(pa.uint32()))
+    def len(self) -> ArrowSeries:
+        return self.with_native(pc.list_value_length(self.native).cast(pa.uint32()))
+
+    unique = not_implemented()
+    contains = not_implemented()
