@@ -30,6 +30,7 @@ from narwhals.dependencies import (
 )
 
 if TYPE_CHECKING:
+    from collections.abc import Collection, Sized
     from types import ModuleType
     from typing import ClassVar
 
@@ -39,7 +40,7 @@ if TYPE_CHECKING:
     import pyarrow as pa
     import pyspark.sql as pyspark_sql
     from pyspark.sql.connect.dataframe import DataFrame as PySparkConnectDataFrame
-    from typing_extensions import TypeAlias, TypeIs
+    from typing_extensions import Self, TypeAlias, TypeIs
 
     from narwhals._arrow.namespace import ArrowNamespace
     from narwhals._dask.namespace import DaskNamespace
@@ -98,10 +99,35 @@ if TYPE_CHECKING:
         Implementation.POLARS,
     ]
 
+    class _BasePandasLike(Sized, Protocol):
+        index: Any
+        """`mypy` doesn't like the asymmetric `property` setter in `pandas`."""
+
+        def __getitem__(self, key: Any, /) -> Any: ...
+        def __mul__(self, other: float | Collection[float] | Self) -> Self: ...
+        def __floordiv__(self, other: float | Collection[float] | Self) -> Self: ...
+        @property
+        def loc(self) -> Any: ...
+        @property
+        def shape(self) -> tuple[int, ...]: ...
+        def set_axis(self, labels: Any, *, axis: Any = ..., copy: bool = ...) -> Self: ...
+        def copy(self, deep: bool = ...) -> Self: ...  # noqa: FBT001
+        def rename(self, *args: Any, inplace: Literal[False], **kwds: Any) -> Self:
+            """`inplace=False` is required to avoid (incorrect?) default overloads."""
+            ...
+
+    class _BasePandasLikeFrame(NativeFrame, _BasePandasLike, Protocol): ...
+
+    class _BasePandasLikeSeries(NativeSeries, _BasePandasLike, Protocol):
+        def where(self, cond: Any, other: Any = ..., **kwds: Any) -> Any: ...
+
     class _NativeDask(Protocol):
         _partition_type: type[pd.DataFrame]
 
-    class _NativeCuDF(Protocol):
+    class _CuDFDataFrame(_BasePandasLikeFrame, Protocol):
+        def to_pylibcudf(self, *args: Any, **kwds: Any) -> Any: ...
+
+    class _CuDFSeries(_BasePandasLikeSeries, Protocol):
         def to_pylibcudf(self, *args: Any, **kwds: Any) -> Any: ...
 
     class _NativeIbis(Protocol):
@@ -110,10 +136,10 @@ if TYPE_CHECKING:
         def __pandas_result__(self, *args: Any, **kwds: Any) -> Any: ...
         def __polars_result__(self, *args: Any, **kwds: Any) -> Any: ...
 
-    class _ModinDataFrame(Protocol):
+    class _ModinDataFrame(_BasePandasLikeFrame, Protocol):
         _pandas_class: type[pd.DataFrame]
 
-    class _ModinSeries(Protocol):
+    class _ModinSeries(_BasePandasLikeSeries, Protocol):
         _pandas_class: type[pd.Series[Any]]
 
     _NativePolars: TypeAlias = "pl.DataFrame | pl.LazyFrame | pl.Series"
@@ -121,7 +147,12 @@ if TYPE_CHECKING:
     _NativeDuckDB: TypeAlias = "duckdb.DuckDBPyRelation"
     _NativePandas: TypeAlias = "pd.DataFrame | pd.Series[Any]"
     _NativeModin: TypeAlias = "_ModinDataFrame | _ModinSeries"
-    _NativePandasLike: TypeAlias = "_NativePandas | _NativeCuDF | _NativeModin"
+    _NativeCuDF: TypeAlias = "_CuDFDataFrame | _CuDFSeries"
+    _NativePandasLikeSeries: TypeAlias = "pd.Series[Any] | _CuDFSeries | _ModinSeries"
+    _NativePandasLikeDataFrame: TypeAlias = (
+        "pd.DataFrame | _CuDFDataFrame | _ModinDataFrame"
+    )
+    _NativePandasLike: TypeAlias = "_NativePandasLikeDataFrame |_NativePandasLikeSeries"
     _NativeSQLFrame: TypeAlias = "SQLFrameDataFrame"
     _NativePySpark: TypeAlias = "pyspark_sql.DataFrame"
     _NativePySparkConnect: TypeAlias = "PySparkConnectDataFrame"
@@ -225,42 +256,38 @@ class Namespace(Generic[CompliantNamespaceT_co]):
             Namespace[PolarsNamespace]
         """
         impl = Implementation.from_backend(backend)
-        backend_version = impl._backend_version()
+        backend_version = impl._backend_version()  # noqa: F841
         version = cls._version
         ns: CompliantNamespaceAny
         if impl.is_pandas_like():
             from narwhals._pandas_like.namespace import PandasLikeNamespace
 
-            ns = PandasLikeNamespace(
-                implementation=impl, backend_version=backend_version, version=version
-            )
+            ns = PandasLikeNamespace(implementation=impl, version=version)
 
         elif impl.is_polars():
             from narwhals._polars.namespace import PolarsNamespace
 
-            ns = PolarsNamespace(backend_version=backend_version, version=version)
+            ns = PolarsNamespace(version=version)
         elif impl.is_pyarrow():
             from narwhals._arrow.namespace import ArrowNamespace
 
-            ns = ArrowNamespace(backend_version=backend_version, version=version)
+            ns = ArrowNamespace(version=version)
         elif impl.is_spark_like():
             from narwhals._spark_like.namespace import SparkLikeNamespace
 
-            ns = SparkLikeNamespace(
-                implementation=impl, backend_version=backend_version, version=version
-            )
+            ns = SparkLikeNamespace(implementation=impl, version=version)
         elif impl.is_duckdb():
             from narwhals._duckdb.namespace import DuckDBNamespace
 
-            ns = DuckDBNamespace(backend_version=backend_version, version=version)
+            ns = DuckDBNamespace(version=version)
         elif impl.is_dask():
             from narwhals._dask.namespace import DaskNamespace
 
-            ns = DaskNamespace(backend_version=backend_version, version=version)
+            ns = DaskNamespace(version=version)
         elif impl.is_ibis():
             from narwhals._ibis.namespace import IbisNamespace
 
-            ns = IbisNamespace(backend_version=backend_version, version=version)
+            ns = IbisNamespace(version=version)
         else:
             msg = "Not supported Implementation"  # pragma: no cover
             raise AssertionError(msg)
@@ -275,8 +302,8 @@ class Namespace(Generic[CompliantNamespaceT_co]):
     @overload
     @classmethod
     def from_native_object(
-        cls, native: _NativePandasLike, /
-    ) -> Namespace[PandasLikeNamespace]: ...
+        cls, native: _NativePandas, /
+    ) -> Namespace[PandasLikeNamespace[pd.DataFrame, pd.Series[Any]]]: ...
 
     @overload
     @classmethod
@@ -302,6 +329,24 @@ class Namespace(Generic[CompliantNamespaceT_co]):
     @classmethod
     def from_native_object(cls, native: _NativeIbis, /) -> Namespace[IbisNamespace]: ...
 
+    @overload
+    @classmethod
+    def from_native_object(
+        cls, native: _NativeModin, /
+    ) -> Namespace[PandasLikeNamespace[_ModinDataFrame, _ModinSeries]]: ...
+
+    @overload
+    @classmethod
+    def from_native_object(
+        cls, native: _NativeCuDF, /
+    ) -> Namespace[PandasLikeNamespace[_CuDFDataFrame, _CuDFSeries]]: ...
+
+    @overload
+    @classmethod
+    def from_native_object(
+        cls, native: _NativePandasLike, /
+    ) -> Namespace[PandasLikeNamespace[Any, Any]]: ...
+
     @overload
     @classmethod
     def from_native_object(
@@ -309,36 +354,37 @@ class Namespace(Generic[CompliantNamespaceT_co]):
     ) -> Namespace[CompliantNamespaceAny]: ...
 
     @classmethod
-    def from_native_object(  # noqa: PLR0911
+    def from_native_object(
         cls: type[Namespace[Any]], native: NativeAny, /
     ) -> Namespace[Any]:
         if is_native_polars(native):
-            return cls.from_backend(Implementation.POLARS)
+            impl = Implementation.POLARS
         elif is_native_pandas(native):
-            return cls.from_backend(Implementation.PANDAS)
+            impl = Implementation.PANDAS
         elif is_native_arrow(native):
-            return cls.from_backend(Implementation.PYARROW)
+            impl = Implementation.PYARROW
         elif is_native_spark_like(native):
-            return cls.from_backend(
+            impl = (
                 Implementation.SQLFRAME
                 if is_native_sqlframe(native)
                 else Implementation.PYSPARK_CONNECT
                 if is_native_pyspark_connect(native)
                 else Implementation.PYSPARK
             )
-        elif is_native_dask(native):
-            return cls.from_backend(Implementation.DASK)  # pragma: no cover
+        elif is_native_dask(native):  # pragma: no cover
+            impl = Implementation.DASK
         elif is_native_duckdb(native):
-            return cls.from_backend(Implementation.DUCKDB)
+            impl = Implementation.DUCKDB
         elif is_native_cudf(native):  # pragma: no cover
-            return cls.from_backend(Implementation.CUDF)
+            impl = Implementation.CUDF
         elif is_native_modin(native):  # pragma: no cover
-            return cls.from_backend(Implementation.MODIN)
+            impl = Implementation.MODIN
         elif is_native_ibis(native):
-            return cls.from_backend(Implementation.IBIS)
+            impl = Implementation.IBIS
         else:
             msg = f"Unsupported type: {type(native).__qualname__!r}"
             raise TypeError(msg)
+        return cls.from_backend(impl)
 
 
 def is_native_polars(obj: Any) -> TypeIs[_NativePolars]:
